@@ -7,7 +7,7 @@
 ##########################################################
 
 # import std modules
-import pybel, glob, os,shutil, re, argparse, sys, random
+import glob, os,shutil, re, argparse, sys, random, openbabel
 from molSimplify.Classes.mol3D import *
 from molSimplify.Classes.globalvars import *
 from pkg_resources import resource_filename, Requirement
@@ -220,6 +220,33 @@ def getmcores():
         mcores = resource_filename(Requirement.parse("molSimplify"),"molSimplify/Cores/cores.dict")
     mcores = readdict(mcores)
     return mcores
+############################
+### get substrates dictionary ###
+############################
+def getsubstrates():
+    subcores = getsubcores()
+    a=[]
+    for key in subcores:
+        a.append(key)
+    a = sorted(a)
+    a = ' '.join(a)
+    return a
+#############################
+### get subcores          ###
+#############################
+def getsubcores():
+    ## this form of the functionn
+    ## is used extensively in the GUI
+    ## so it got it's own call. This
+    ## is basically the same as getsubstrates() but
+    ## returns the full dictionary
+    globs = globalvars()
+    if globs.custom_path: # test if a custom path is used:
+         subcores = str(globs.custom_path).rstrip('/') + "/Substrates/substrates.dict"
+    else:
+        subcores = resource_filename(Requirement.parse("molSimplify"),"molSimplify/Substrates/substrates.dict")
+    subcores = readdict(subcores)
+    return subcores
 #######################
 ### load bonds data ###
 #######################
@@ -277,25 +304,24 @@ def core_load(usercore,mcores):
     core = mol3D() # initialize core molecule
     ### check if core exists in dictionary
     if usercore.lower() in mcores.keys():
+        print('loading core from dictionary')
         dbentry = mcores[usercore.lower()]
         # load core mol file (with hydrogens
         if globs.custom_path:
             fcore = globs.custom_path + "/Cores/" +dbentry[0]
         else:
             fcore = resource_filename(Requirement.parse("molSimplify"),"molSimplify/Cores/" +dbentry[0])
-
         # check if core xyz/mol file exists
         if not glob.glob(fcore):
             emsg ="We can't find the core structure file %s right now! Something is amiss. Exiting..\n" % fcore
             print emsg
             return False,emsg
         if ('.xyz' in fcore):
-            core.OBmol = core.getOBmol(fcore,'xyzf')
+            core.OBMol = core.getOBMol(fcore,'xyzf')
         elif ('.mol' in fcore):
-            core.OBmol = core.getOBmol(fcore,'molf')
+            core.OBMol = core.getOBMol(fcore,'molf')
         elif ('.smi' in fcore):
-            core.OBmol = core.getOBmol(fcore,'smif')
-            core.OBmol.make3D('mmff94',0) # generate 3D coords
+            core.OBMol = core.getOBMol(fcore,'smif')
         core.cat = [int(l) for l in filter(None,dbentry[1])]
         core.denticity = dbentry[2]
         core.ident = usercore
@@ -303,11 +329,11 @@ def core_load(usercore,mcores):
     elif ('.mol' in usercore or '.xyz' in usercore or '.smi' in usercore):
         if glob.glob(usercore):
             ftype = usercore.split('.')[-1]
+            print('Core is a '+ftype+' file')
             # try and catch error if conversion doesn't work
             try:
-                core.OBmol = core.getOBmol(usercore,ftype+'f') # convert from file
-                if 'smi' in usercore:
-                    core.OBmol.make3D('mmff94',0)
+                core.OBMol = core.getOBMol(usercore,ftype+'f') # convert from file
+                print('Core successfully converted to OBMol')
             except IOError:
                 emsg = 'Failed converting file ' +usercore+' to molecule..Check your file.\n'
                 print emsg
@@ -324,8 +350,8 @@ def core_load(usercore,mcores):
         usercore = checkTMsmiles(usercore)
         # try and catch error if conversion doesn't work
         try:
-            core.OBmol = core.getOBmol(usercore,'smi') # convert from smiles
-            core.OBmol.make3D('mmff94',0) # add hydrogens and coordinates
+            core.OBMol = core.getOBMol(usercore,'smi') # convert from smiles
+            print('Core successfully interpreted as smiles')
         except IOError:
             emsg = "We tried converting the string '%s' to a molecule but it wasn't a valid SMILES string.\n" % usercore
             emsg += "Furthermore, we couldn't find the core structure: '%s' in the cores dictionary. Try again!\n" % usercore
@@ -336,7 +362,78 @@ def core_load(usercore,mcores):
         core.denticity = 1
         core.ident = 'core'
     return core,emsg
-    
+
+#############################
+###    load substrate and ###
+### convert to molecule   ### 
+#############################
+def substr_load(usersubstrate,subcores):
+    globs = globalvars()
+    if '~' in usersubstrate:
+        homedir = os.path.expanduser("~")
+        usersubstrate = usersubstrate.replace('~',homedir)
+    emsg = False
+    substrate = mol3D() # initialize core molecule
+    ### check if core exists in dictionary
+    if usersubstrate.lower() in subcores.keys():
+        print('loading substrate from dictionary')
+        dbentry = subcores[usersubstrate.lower()]
+        # load substrate mol file (with hydrogens
+        if globs.custom_path:
+            fsubst = globs.custom_path + "/Substrates/" +dbentry[0]
+        else:
+            fsubst = resource_filename(Requirement.parse("molSimplify"),"molSimplify/Substrates/" +dbentry[0])
+
+        # check if substrate xyz/mol file exists
+        if not glob.glob(fsubst):
+            emsg ="We can't find the substrate structure file %s right now! Something is amiss. Exiting..\n" % fcore
+            print emsg
+            return False,emsg
+        if ('.xyz' in fsubst):
+            substrate.OBMol = substrate.getOBMol(fsubst,'xyzf')
+        elif ('.mol' in fsubst):
+            substrate.OBMol = substrate.getOBMol(fsubst,'molf')
+        elif ('.smi' in fsubst):
+            substrate.OBMol = substrate.getOBMol(fsubst,'smif')
+        substrate.ident = dbentry[1]
+    ### load from file
+    elif ('.mol' in usersubstrate or '.xyz' in usersubstrate or '.smi' in usersubstrate):
+        if glob.glob(usersubstrate):
+            ftype = usersubstrate.split('.')[-1]
+            print('Substrate is a '+ftype+' file')
+            # try and catch error if conversion doesn't work
+            try:
+                substrate.OBMol = substrate.getOBMol(usersubstrate,ftype+'f') # convert from file
+                print('Substrate successfully converted to OBMol')
+            except IOError:
+                emsg = 'Failed converting file ' +usersubstrate+' to molecule..Check your file.\n'
+                print emsg
+                return False,emsg
+            substrate.ident = usersubstrate.split('.')[0]
+            substrate.ident = substrate.ident.rsplit('/')[-1]
+        else:
+            emsg = 'Substrate file '+usersubstrate+' does not exist. Exiting..\n'
+            print emsg
+            return False,emsg
+    ### if not, try converting from SMILES
+    else:
+        # check for transition metals
+        usersubstrate = checkTMsmiles(usersubstrate)
+        # try and catch error if conversion doesn't work
+        try:
+            substrate.OBMol = substrate.getOBMol(usersubstrate,'smi') # convert from smiles
+            print('Substrate successfully interpreted as smiles')
+        except IOError:
+            emsg = "We tried converting the string '%s' to a molecule but it wasn't a valid SMILES string.\n" % usercore
+            emsg += "Furthermore, we couldn't find the substrate structure: '%s' in the substrates dictionary. Try again!\n" % usercore
+            emsg += "\nAvailable substrates are: %s\n" % getsubstrates()
+            print emsg
+            return False,emsg
+        substrate.cat = [0]
+        substrate.denticity = 1
+        substrate.ident = 'substrate'
+    return substrate,emsg
+   
 ###########################
 ###   load ligand and   ###
 ### convert to molecule ###
@@ -360,6 +457,7 @@ def lig_load(userligand,licores):
     lig = mol3D() # initialize ligand molecule
     ### check if ligand exists in dictionary
     if userligand in licores.keys():
+        print('loading ligand from dictionary')
         dbentry = licores[userligand]
         # load lig mol file (with hydrogens)
         if globs.custom_path:
@@ -372,13 +470,11 @@ def lig_load(userligand,licores):
             print emsg
             return False, emsg
         if ('.xyz' in flig):
-            lig.OBmol = lig.getOBmol(flig,'xyzf')
+            lig.OBMol = lig.getOBMol(flig,'xyzf')            
         elif ('.mol' in flig):
-            lig.OBmol = lig.getOBmol(flig,'molf')
+            lig.OBMol = lig.getOBMol(flig,'molf')
         elif ('.smi' in flig):
-            lig.OBmol = lig.getOBmol(flig,'smif')
-            # generate coordinates if not existing
-            lig.OBmol.make3D('mmff94',0) # add hydrogens and coordinates
+            lig.OBMol = lig.getOBMol(flig,'smif')
         ### modified the check for length,
         ### as it parsing string length instead of
         ### list length!
@@ -387,7 +483,7 @@ def lig_load(userligand,licores):
         else:
            lig.denticity = len(dbentry[2])
         lig.ident = dbentry[1]
-        lig.charge = lig.OBmol.charge
+        lig.charge = lig.OBMol.GetTotalCharge()
         if 'pi' in dbentry[2]:
             lig.cat = [int(l) for l in dbentry[2][:-1]]
             lig.cat.append('pi')
@@ -402,41 +498,33 @@ def lig_load(userligand,licores):
             lig.grps = []
         if len(dbentry) > 3:
             lig.ffopt = dbentry[4][0]
-        ### load from file
-        #print('dent is ' + str(lig.denticity))
+    ### load from file
     elif ('.mol' in userligand or '.xyz' in userligand or '.smi' in userligand or '.sdf' in userligand):
-        if glob.glob(userligand):
-            ftype = userligand.split('.')[-1]
+        flig = resource_filename(Requirement.parse("molSimplify"),"molSimplify/" +userligand)
+        if glob.glob(flig):
+            ftype = flig.split('.')[-1]
             # try and catch error if conversion doesn't work
             try:
-                lig.OBmol = lig.getOBmol(userligand,ftype+'f') # convert from smiles
+                print('ligand is an '+ftype+' file')
+                lig.OBMol = lig.getOBMol(flig,ftype+'f') # convert from file
                 # generate coordinates if not existing
-                if lig.OBmol.dim==0:
-                    lig.OBmol.make3D('mmff94',0) # add hydrogens and coordinates
-                lig.charge = lig.OBmol.charge
+                lig.charge = lig.OBMol.GetTotalCharge()
+                print('Ligand successfully converted to OBMol')
             except IOError:
                 emsg = 'Failed converting file ' +userligand+' to molecule..Check your file.\n'
                 return False,emsg
-            lig.ident = userligand.rsplit('/')[-1]
+            lig.ident = flig.rsplit('/')[-1]
             lig.ident = lig.ident.split('.'+ftype)[0]
         else:
             emsg = 'Ligand file '+userligand+' does not exist. Exiting..\n'
             print emsg
             return False,emsg
-    ### if not, try converting from SMILES
+    ### if not, try interpreting as SMILES string
     else:
-        # check for transition metals
-        #userligand = checkTMsmiles(userligand)
-        # try and catch error if conversion doesn't work
         try:
-            if globs.debug:
-                print userligand
-            lig.OBmol = lig.getOBmol(userligand,'smi') # convert from smiles
-            lig.OBmol.make3D('mmff94',0) # add hydrogens and coordinates
-            #lig.OBmol.write(format='mol', filename='smilig.mol', overwrite=True)
-            #lig.OBmol = lig.getOBmol('smilig.mol','molf')
-            #os.remove('smilig.mol')
-            lig.charge = lig.OBmol.charge
+            lig.OBMol = lig.getOBMol(userligand,'smistring') # convert from smiles
+            lig.charge = lig.OBMol.GetTotalCharge()
+            print('Ligand successfully interpreted as SMILES')
         except IOError:
             emsg = "We tried converting the string '%s' to a molecule but it wasn't a valid SMILES string.\n" % userligand
             emsg += "Furthermore, we couldn't find the ligand structure: '%s' in the ligands dictionary. Try again!\n" % userligand
@@ -474,22 +562,20 @@ def bind_load(userbind,bindcores):
             print emsg
             return False,False,emsg
         if ('.xyz' in fbind):
-            bind.OBmol = bind.getOBmol(fbind,'xyzf')
+            bind.OBMol = bind.getOBMol(fbind,'xyzf')
         elif ('.mol' in fbind):
-            bind.OBmol = bind.getOBmol(fbind,'molf')
+            bind.OBMol = bind.getOBMol(fbind,'molf')
         elif ('.smi' in fbind):
-            bind.OBmol = bind.getOBmol(fbind,'smif')
-        bind.charge = bind.OBmol.charge
+            bind.OBMol = bind.getOBMol(fbind,'smif')
+        bind.charge = bind.OBMol.GetTotalCharge()
     ### load from file
     elif ('.mol' in userbind or '.xyz' in userbind or '.smi' in userbind):
         if glob.glob(userbind):
             ftype = userbind.split('.')[-1]
             # try and catch error if conversion doesn't work
             try:
-                bind.OBmol = bind.getOBmol(userbind,ftype+'f') # convert from file
-                if bind.OBmol.dim==0:
-                    bind.OBmol.make3D('mmff94',0) # add hydrogens and coordinates
-                bind.charge = bind.OBmol.charge
+                bind.OBMol = bind.getOBMol(userbind,ftype+'f') # convert from file
+                bind.charge = bind.OBMol.GetTotalCharge()
             except IOError:
                 emsg = 'Failed converting file ' +userbind+' to molecule..Check your file.\n'
                 return False,emsg
@@ -504,9 +590,8 @@ def bind_load(userbind,bindcores):
         userbind = checkTMsmiles(userbind)
         # try and catch error if conversion doesn't work
         try:
-            bind.OBmol = bind.getOBmol(userbind,'smi') # convert from smiles
-            bind.OBmol.make3D('mmff94',0) # add hydrogens and coordinates
-            bind.charge = bind.OBmol.charge
+            bind.OBMol = bind.getOBMol(userbind,'smi') # convert from smiles
+            bind.charge = bind.OBMol.GetTotalCharge()
             bsmi = True
             bind.ident = 'smi'
         except IOError:
@@ -591,7 +676,6 @@ def get_name(args,rootdir,core,ligname,bind = False,bsmi = False):
 def name_complex(rootdir,core,ligs,ligoc,sernum,args,bind= False,bsmi=False):
     ## new version of the above, designed to 
     ## produce more human and machine-readable formats
-    romans={'I':'1','II':'2','III':'3','IV':'4','V':'5','VI':'6'}
     if args.name: # if set externerally
         name = rootdir+'/'+args.name
     else:
@@ -628,6 +712,38 @@ def name_complex(rootdir,core,ligs,ligoc,sernum,args,bind= False,bsmi=False):
                     name += "_" + +args.nambsmi[0:2]
     return name
 
+def name_TS(rootdir,core,subst,args,bind= False,bsmi=False):
+    ## new version of the above, designed to 
+    ## produce more human and machine-readable formats
+    globs = globalvars()
+    if args.name: # if set externerally
+        name = rootdir+'/'+args.name
+    else:
+        try:
+            center = core.getAtom(0).symbol().lower()
+        except:
+            center = str(core).lower()
+        name = rootdir + '/' + center
+        #if args.oxstate:
+            #if args.oxstate in romans.keys():
+                #ox = str(romans[args.oxstate])
+            #else:
+                #ox = str(args.oxstate)
+        #else:
+            #ox = "0"
+        #name += "_" + str(ox)
+        if args.spin:
+            spin = str(args.spin)
+        else:
+            spin = "0"
+        name += "_s_"+str(spin)
+        name += "_" + str(subst.ident) + "_TS"
+        if args.bind:
+            if bsmi:
+                if args.nambsmi: # if name specified use it in file
+                    name += "_" + +args.nambsmi[0:2]
+    return name
+
 ##############################################
 ### function to copy ligands, bind and     ###
 ### cores to user-specified path       ###
