@@ -32,7 +32,7 @@ from molSimplify.Classes.globalvars import *
 
 globs = globalvars()
 DescString_basic = 'Welcome to molSimplify. Only basic usage is described here.\n'
-DescString_basic += 'For help on advanced modules, please refer to our documentation at WEBLINK or provide additional commands to -h, as below:\n'
+DescString_basic += 'For help on advanced modules, please refer to our documentation at molsimplify.mit.edu or provide additional commands to -h, as below:\n'
 DescString_basic += '-h advanced: advanced structure generation help\n'
 DescString_basic += '-h slabgen: slab builder help\n'
 #DescString_basic += '-h chainb: chain builder help\n'
@@ -43,6 +43,7 @@ DescString_basic += '-h postproc: post-processing help\n'
 DescString_basic += '-h random: random generation help\n'
 DescString_basic += '-h binding: binding species (second molecule) generation help\n'
 DescString_basic += '-h customcore: custom core functionalization help\n'
+DescString_basic += '-h tsgen: transition state generation help\n'
 DescString_basic += '-h naming: custom filename help\n'
 
 DescString_advanced = 'Printing advanced structure generation help.'
@@ -54,6 +55,7 @@ DescString_inputgen = 'Printing quantum chemistry code input file generation hel
 DescString_postproc = 'Printing post-processing help.'
 DescString_random = 'Printing random generation help.'
 DescString_binding = 'Printing binding species (second molecule) generation help.'
+DescString_tsgen = 'Printing transition state generation help.'
 DescString_customcore = 'Printing custom core functionalization help.'
 DescString_naming = 'Printing custom filename help.'
 
@@ -69,7 +71,6 @@ except ImportError:
 def main(args=None):
     if args is None:
         args = sys.argv[1:]
-    print(args)
     ### run GUI by default ###
     args = sys.argv[1:]
     gui = True
@@ -89,9 +90,9 @@ def main(args=None):
     #    elif 'chainb' in args:
     #        parser = argparse.ArgumentParser(description=DescString_chainb)
     #        parseinputs_chainb(parser)            
-        elif 'autocorr' in args:
-            parser = argparse.ArgumentParser(description=DescString_autocorr)
-            parseinputs_autocorr(parser)           
+    #    elif 'autocorr' in args:
+    #        parser = argparse.ArgumentParser(description=DescString_autocorr)
+    #        parseinputs_autocorr(parser)           
         elif 'db' in args:
             parser = argparse.ArgumentParser(description=DescString_db)
             parseinputs_db(parser)       
@@ -107,6 +108,9 @@ def main(args=None):
         elif 'binding' in args:
             parser = argparse.ArgumentParser(description=DescString_binding)
             parseinputs_binding(parser)            
+        elif 'tsgen' in args:
+            parser = argparse.ArgumentParser(description=DescString_tsgen)
+            parseinputs_tsgen(parser)            
         elif 'customcore' in args:
             parser = argparse.ArgumentParser(description=DescString_customcore)
             parseinputs_customcore(parser) 
@@ -141,7 +145,6 @@ def main(args=None):
         # create input file from commandline
         infile = parseCLI(filter(None,args))
         args = ['main.py','-i',infile]
-        print args
         emsg = startgen(args,False,gui)
 if __name__ == '__main__':
     main()
